@@ -15,7 +15,8 @@ class Base(LoggedObject):
 
     """
 
-    def __init__(self, func: callable) -> None:
+    def __init__(self, func: callable, **kwargs) -> None:
+        super().__init__(**kwargs)
         self.history = []
         self.start = datetime.now()
         self.func = func
@@ -23,6 +24,24 @@ class Base(LoggedObject):
     def _get_time_from_start(self) -> int:
         return (datetime.now() - self.start).microseconds
 
+    def _update_history(
+            self,
+            point: np.ndarray,
+            loss: float = None,
+            generation: int = None,
+    ):
+        _loss = loss if loss is not None else self.func(point)
+        _generation = generation if generation else len(self.history)
+        self.history.append(
+            (point, _loss, self._get_time_from_start())
+        )
+        self.logger.info(
+            f'Generation: {_generation}.'
+            f' Loss: {self.history[-1][1]}.'
+            f' Optimization Time: {self.history[-1][2]} msec.'
+            f' Point: {str(self.history[-1][0])}.'
+        )
+
     def fill_history(self) -> None:
         pass
 
