@@ -15,3 +15,7 @@ def rastrigin(point):
             (point ** 2 - factor * np.cos(2 * np.pi * point)).sum()
             + factor * point.size
     )
+
+
+def rosenbrock(point):
+    return (1 - point[0]) ** 2 + 100 * (point[1] - point[0] ** 2) ** 2
