@@ -19,12 +19,12 @@ test_points_rmo = []
 for func, point in zip(FUNCTIONS, INITIAL_POINTS):
     RMO = RadialMovementOptimization(
         func=func,
-        generations_number=10000,
-        particles_number=10,
-        bounds=(-5.12, 5.12),
-        c_parameters=(0.6, 0.7),
-        weight_limits=(0, 1),
-        scale=2,
+        generations_number=20000,
+        particles_number=100,
+        bounds=[(-5.12, 5.12) for _ in range(point.size)],
+        c_parameters=(0.7, 0.8),
+        weight_limits=(0, .5),
+        scale=1,
     )
     test_points_rmo.append(RMO.run(point=point)[0])
 
